REM  *****  BASIC  *****
sub Leerzeichen_ersetzen
  REM Das Ziel dieses Makros ist es, an einer Reihe von Stellen
  REM ein geschütztes Leerzeichen (U+00A0 = 160, No-Break Space) einzufügen.
  REM (Für ein schmales geschütztes Leerzeichen 
  REM kann man U+202F = 8239 (Narrow No-Break Space) verwenden.)
  REM Die Ersetzungen werden in zwei große Gruppen eingeteilt:
  REM - es werden keine regulären Ausdrücke verwendet
  REM - es werden reguläre Ausdrücke verwendet
  REM Falls reguläre Ausdrücke verwendet werden, 
  REM werden folgende Gruppen unterschieden:
  REM - geschütztes Leerzeichen am Ende, z. B. "Dr. Meier"
  REM - geschütztes Leerzeichen am Anfang, z. B. "3 %"
  REM - geschütztes Leerzeichen in der Mitte, z. B. "Art. 4"
  REM - physikalische Einheiten
  REM Quelle (und Dank an): Pitonyak/Lenhardt, S. 385 +/- epsilon

  Dim oErsetzen
  oErsetzen = ThisComponent.createReplaceDescriptor()

REM ----- keine regulären Ausdrücke -----

  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "Nr. " 'Nr.
    .ReplaceString = "Nr." & CHR$(160)
    .SearchRegularExpression = FALSE  'Reguläre Ausdrücke verwenden? Bis auf Weiteres nicht.
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchString = "e. V."
    .ReplaceString = "e." & CHR$(160) & "V."
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchString = "Hartz IV"
    .ReplaceString = "Hartz" & CHR$(160)& "IV"
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchString = "Stuttgart 21"
    .ReplaceString = "Stuttgart" & CHR$(160)& "21"
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchString = "etc. pp."
    .ReplaceString = "etc." & CHR$(160)& "pp."
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchString = "IDW S1"
    .ReplaceString = "IDW" & CHR$(160)& "S1"
  End With
  ThisComponent.replaceAll(oErsetzen)

REM ------Ab hier wird mit regulären Ausdrücken gearbeitet.  
REM ----- Leerzeichen steht am Ende

  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "(Prof\.|Dr\.|Mr\.|Mrs\.|Ms\.) " 'Prof., Dr., Mr. ...
    .ReplaceString = "$1" & CHR$(160)
    .SearchRegularExpression = TRUE  'Reguläre Ausdrücke verwenden? Ab hier ja.
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "(gem\.|§|Abs\.) " 'gem., §, Abs.
    .ReplaceString = "$1" & CHR$(160)
  End With
  ThisComponent.replaceAll(oErsetzen)

  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= " (ca\.|no\.|S\.) " 'ca., no., S.
    .ReplaceString = " $1" & CHR$(160)
  End With
  ThisComponent.replaceAll(oErsetzen)

REM ----- Leerzeichen steht am Anfang

  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= " (–|%|‰|&|f\.|ff\.)" '– % ‰ & f. ff.
    .ReplaceString = CHR$(160) & "$1"
  End With
  ThisComponent.replaceAll(oErsetzen)

REM ----- Leerzeichen steht in der Mitte

' Datumsangaben
  ThisComponent.replaceAll(oErsetzen)
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([0-3]{0,1}[:digit:]{0,1}\.) " &_
    "(Jan\.|Feb\.|Mrz\.|Apr\.|Jun\.|Jul\.|Aug\.|Sept\.|Okt\.|Nov\.|Dez\.|Januar|Februar|März|April|Mai|Juni|Juli|August|September|Oktober|November|Dezember)"
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Art. 1 / para. 2 / PFA 3
  ThisComponent.replaceAll(oErsetzen)
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "( Art\.| para\.| PFA) ([:digit:]+)"
    .ReplaceString = "$1" & CHR$(160) & "$2"'
  End With
  ThisComponent.replaceAll(oErsetzen)

' Meyer & Co., Meyer & Co. KG, Meyer & Co. SE
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "& Co. ([KG|SE])"
    .ReplaceString = "\&" & CHR$(160) & "Co." & CHR$(160) & "$1"
  End With
  ThisComponent.replaceAll(oErsetzen)

' SGB I...IX (!)
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "SGB (I|V)"
    .ReplaceString = "SGB" & CHR$(160) & "$1"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Phase I, Planungsphase II (!)
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "([P|p]hase) I"
    .ReplaceString = "$1" & CHR$(160) & "I"
  End With
  ThisComponent.replaceAll(oErsetzen)

' k. o., K. o.
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "(k\.|K\.) o\."
    .ReplaceString = "$1" & CHR$(160) & "o."
  End With
  ThisComponent.replaceAll(oErsetzen)

' 24. BImSchV
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString= "([:digit:]+\.) BImSchV"
    .ReplaceString = "$1" & CHR$(160) & "BImSchV"
  End With
  ThisComponent.replaceAll(oErsetzen)

' ISO-Normen
  ThisComponent.replaceAll(oErsetzen)
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "ISO ([:digit:]+)" 'Artikel: Art. Aber nicht "die Art."
    .ReplaceString = "ISO" & CHR$(160) & "$1"'
  End With
  ThisComponent.replaceAll(oErsetzen)

REM physikalische Einheiten
REM Wenn bei einer Einheit ein geschütztes Leerzeichen fehlt, liegt das daran,
REM dass sie bei mir noch nicht vorkam ;-)
REM Bei Meter kann man sich Anregungen holen.

REM Meter: m, mm, cm, km, Nm, m², m³
REM Erkannt werden soll:
REM - mindestens eine Ziffer (die ergeben $1), gefolgt von
REM - einem Leerzeichen, das ersetzt werden soll, gefolgt von
REM - einem oder keinem m, c, k, N
REM   (genauer: keinem einem oder mehreren, aber mit diesem Fehler kann ich leben),
REM   gefolgt von
REM - einem "m" für "Meter", gefolgt von
REM - einer schließende eckigen Klammer, einem Schrägstrich, Punkt, Komma, Semikolon, 
REM   Doppelpunkt, Leerzeichen, Ausrufezeichen, Fragezeichen, einer 
REM   einer schließenden runden Klammer, einer "²" oder einer "³";
REM was hinter dem Leerzeichen kommt, ergibt $2

' Meter: m, m², m³, Nm
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) ([mckN]*m[\]/.,;: !?\)²³])" 'm/, m., ... m)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Hektar: ha  
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) (ha[\]/.,;: !?\)])" 'ha/, ha., ... ha)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Gramm: g, mg, kg
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) ([mk]*g[\]/.,;: !?\)])" 'g/, g., ... g)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Volt: V, mV, kV
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) ([mk]*V[\]/.,;: !?\)])" 'V/, V., ... V)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Ampere: A, mA
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) ([m]*A[\]/.,;: !?\)])" 'A/, A., ... A)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Watt: W, mW, kW, MW, GW, Wh
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) ([mkMG]*W[\]/.,;: !?\)h])"  'W/, W., ... W)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Hertz: Hz, kHz, MHz, GHz
  With oErsetzen
    .SearchCaseSensitive = True    
    .SearchString = "([:digit:]+) ([kMG]*Hz[\]/.,;: !?\)])" 'Hz/, Hz., ... Hz)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' bar
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) (bar[\]/.,;: !?\)])" 'bar/, bar., ... bar)
    .ReplaceString = "$1" & CHR$(160) & "$2"'
  End With
  ThisComponent.replaceAll(oErsetzen)

' Millisievert: mSv
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) (mSv[\]/.,;: !?\)])" 'mSv/, mSv., ... mSv)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Bequerel: Bq
  With oErsetzen
    .SearchCaseSensitive = True
    .SearchString = "([:digit:]+) (Bq[\]/.,;: !?\)])" 'Bq/, Bq., ... Bq)
    .ReplaceString = "$1" & CHR$(160) & "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

' Dezibel: dB, dB(A)
  With oErsetzen
    .SearchCaseSensitive = TRUE
    .SearchString = "([:digit:]+) (dB[\]/.,;: !?\(\)])" 'dB/, dB., ... dB(A), dB)
    .ReplaceString = "$1" & CHR$(160)& "$2"
  End With
  ThisComponent.replaceAll(oErsetzen)

end sub

